@@ -16,11 +16,11 @@ function(sTree, gTree, assoc, ploidy, dmvD, node) {
 # Note:     branching times = distance from each node to the tips, 
 #            under the assumption that the tree is ultrametric
 
-#  dbgBool = get("P2C2M.flg.dbgBool", envir=p2c2m.globalVars)
-#  if (dbgBool) {
-#    cat("\n", xtermStyle::style("DEBUGMODE> calchelpers.brprob", fg="red"),
-#        sep="")
-#  }
+  debugBool = get("P2C2M_flg_dbgBool", envir=P2C2M_globalVars)
+  if (debugBool) {
+    cat("\n", xtermStyle::style("DEBUG> calchelpers.brprob", fg="red"),
+        sep="")
+  }
 
     ind = calchelpers.gtreeparse(sTree, gTree, assoc, dmvD, node)
 
