@@ -8,9 +8,9 @@ function (post_dist, post_pred_dist) {
   # I/p:      post_dist
   #           post_pred_dist
 
-  dbgBool = get("P2C2M.flg.dbgBool", envir=p2c2m.globalVars)
-  if (dbgBool) {
-    cat("\n", xtermStyle::style("DEBUGMODE> statshelpers.diffrnce", 
+  debugBool = get("P2C2M_flg_dbgBool", envir=P2C2M_globalVars)
+  if (debugBool) {
+    cat("\n", xtermStyle::style("DEBUG> statshelpers.diffrnce", 
         fg="red"), sep="")
   }
 
